@@ -1,9 +1,3 @@
-#' @export
-print.term <- function(x, ...) {
-  print(as.character(x))
-  invisible(x)
-}
-
 #' @export
 print.mcmcarray <- function(x, ...) {
   print(summary(x))
