@@ -1,5 +1,3 @@
-context("split_chains")
-
 test_that("split_chains.mcmcarray", {
   x <- split_chains(mcmcr_example[[2]])
   expect_is(x, "mcmcarray")
@@ -8,9 +6,11 @@ test_that("split_chains.mcmcarray", {
 })
 
 test_that("split_chains 1 iterations", {
-  x <- subset(mcmcr_example, iterations = 1L)
-  expect_error(split_chains(x), "x must have at least two iterations")
-  x <- subset(mcmcr_example, iterations = 1:2)
+  x <- subset(mcmcr_example, iters = 1L)
+  expect_error(split_chains(x), "^`x` must have at least two iterations[.]$",
+    class = "chk_error"
+  )
+  x <- subset(mcmcr_example, iters = 1:2)
   x <- split_chains(x)
   expect_identical(nchains(x), 4L)
   expect_identical(nsims(x), 4L)
@@ -29,4 +29,3 @@ test_that("collapse_chains.mcmcr2", {
   expect_identical(nchains(x), 4L)
   expect_identical(nsims(x), nsims(mcmcr_example2))
 })
-
